==> percona-xtrabackup-80_8.0.33-27.orig.tar.gz: percona-xtrabackup-8.0.33-27/extra/libkmip/kmippp/CMakeFiles/demo_pp_create.dir/DependInfo.cmake <==
# The set of languages for which implicit dependencies are needed:
set(CMAKE_DEPENDS_LANGUAGES
  "CXX"
  )
# The set of files for implicit dependencies of each language:
set(CMAKE_DEPENDS_CHECK_CXX
  "/mnt/workspace/percona-xtrabackup-8.0-source-tarball-NEW/test/percona-xtrabackup/extra/libkmip/kmippp/demo_create.cpp" "/mnt/workspace/percona-xtrabackup-8.0-source-tarball-NEW/test/percona-xtrabackup/extra/libkmip/kmippp/CMakeFiles/demo_pp_create.dir/demo_create.cpp.o"
  )
set(CMAKE_CXX_COMPILER_ID "GNU")

# Preprocessor definitions for this target.
set(CMAKE_TARGET_DEFINITIONS_CXX
  "BOOST_NO_CXX98_FUNCTION_BASE"
  "HAVE_CONFIG_H"
  "HAVE_TLSv13"
  "LZ4_DISABLE_DEPRECATE_WARNINGS"
  "XTRABACKUP"
  "_FILE_OFFSET_BITS=64"
  "_GNU_SOURCE"
  "_USE_MATH_DEFINES"
  "__STDC_FORMAT_MACROS"
  "__STDC_LIMIT_MACROS"
  )

# The include file search paths:
set(CMAKE_CXX_TARGET_INCLUDE_PATH
  "extra/protobuf/protobuf-3.19.4/src"
  "extra/libedit/libedit-20210910-3.1/src/editline"
  "."
  "include"
  "extra/libkmip/kmippp"
  "extra/libkmip/libkmip/include"
  )

# Targets to which this target links.
set(CMAKE_TARGET_LINKED_INFO_FILES
  "/mnt/workspace/percona-xtrabackup-8.0-source-tarball-NEW/test/percona-xtrabackup/extra/libkmip/kmippp/CMakeFiles/kmippp.dir/DependInfo.cmake"
  "/mnt/workspace/percona-xtrabackup-8.0-source-tarball-NEW/test/percona-xtrabackup/extra/libkmip/libkmip/src/CMakeFiles/kmip.dir/DependInfo.cmake"
  )

# Fortran module output directory.
set(CMAKE_Fortran_TARGET_MODULE_DIR "")

==> percona-xtrabackup-81_8.1.0-1.orig.tar.gz: percona-xtrabackup-8.1.0-1/extra/libkmip/kmippp/CMakeFiles/demo_pp_create.dir/DependInfo.cmake <==
# The set of languages for which implicit dependencies are needed:
set(CMAKE_DEPENDS_LANGUAGES
  "CXX"
  )
# The set of files for implicit dependencies of each language:
set(CMAKE_DEPENDS_CHECK_CXX
  "/mnt/jenkins/workspace/percona-xtrabackup-8.0-RELEASE/test/percona-xtrabackup/extra/libkmip/kmippp/demo_create.cpp" "/mnt/jenkins/workspace/percona-xtrabackup-8.0-RELEASE/test/percona-xtrabackup/extra/libkmip/kmippp/CMakeFiles/demo_pp_create.dir/demo_create.cpp.o"
  )
set(CMAKE_CXX_COMPILER_ID "GNU")

# Preprocessor definitions for this target.
set(CMAKE_TARGET_DEFINITIONS_CXX
  "BOOST_NO_CXX98_FUNCTION_BASE"
  "HAVE_CONFIG_H"
  "HAVE_TLSv13"
  "LZ4_DISABLE_DEPRECATE_WARNINGS"
  "MYSQL_PROJECT"
  "XTRABACKUP"
  "_FILE_OFFSET_BITS=64"
  "_GNU_SOURCE"
  "_USE_MATH_DEFINES"
  "__STDC_FORMAT_MACROS"
  "__STDC_LIMIT_MACROS"
  )

# The include file search paths:
set(CMAKE_CXX_TARGET_INCLUDE_PATH
  "extra/protobuf/protobuf-3.19.4/src"
  "extra/libedit/libedit-20210910-3.1/src/editline"
  "."
  "include"
  "extra/libkmip/kmippp"
  "extra/libkmip/libkmip/include"
  )

# Targets to which this target links.
set(CMAKE_TARGET_LINKED_INFO_FILES
  "/mnt/jenkins/workspace/percona-xtrabackup-8.0-RELEASE/test/percona-xtrabackup/extra/libkmip/kmippp/CMakeFiles/kmippp.dir/DependInfo.cmake"
  "/mnt/jenkins/workspace/percona-xtrabackup-8.0-RELEASE/test/percona-xtrabackup/extra/libkmip/libkmip/src/CMakeFiles/kmip.dir/DependInfo.cmake"
  )

# Fortran module output directory.
set(CMAKE_Fortran_TARGET_MODULE_DIR "")
